Learn R Programming

dpcR (version 0.5)

compare_dens: Plot and Compare Densities

Description

Plot empirical and theoretical density of the result of the digital PCR experiment.

Usage

compare_dens(input, moments = TRUE, ...)

Arguments

input

object of class '>dpcr containing only one run.

moments

logical, if TRUE, both theoretical and empirical moments are printed on the plot.

…

other arguments passed to the plot function.

See Also

moments is used to calculate moments of Poisson distribution.

Examples

Run this code
# NOT RUN {
adpcr_big <- sim_adpcr(m = 35, n = 40, times = 50, pos_sums = FALSE, n_panels = 1)
compare_dens(adpcr_big, moments = TRUE)

# }

Run the code above in your browser using DataLab